@@ -38,7 +38,7 @@ function annotate_body_if(annotation, state) {
 }
 
 function annotate_by_id_if(element_id, annotation, state) {
-    element = document.getElementById(element_id);
+    const element = document.getElementById(element_id);
     if (!element) return;
     if (state) element.classList.add(annotation);
     else element.classList.remove(annotation);
@@ -182,9 +182,12 @@ function check_sso_provider_perms() {
 }
 
 async function check_bg_sso_enabled() {
-    let [tab] = await chrome.tabs.query({ currentWindow: true, active: true });
+    const [tab] = await chrome.tabs.query({
+        currentWindow: true,
+        active: true,
+    });
     if (
-        !Object.hasOwn(tab, "url") ||
+        !tab?.url ||
         !tab.url.startsWith("https://") ||
         tab.url.startsWith(sso_url)
     ) {
@@ -193,7 +196,7 @@ async function check_bg_sso_enabled() {
     }
     annotate_by_id_if("bg-sso-state", "hidden", false);
 
-    var tab_hostname = new URL(tab.url).hostname;
+    const tab_hostname = new URL(tab.url).hostname;
     current_filter = "https://" + tab_hostname + "/*";
     set_text_cropped(document.getElementById("current-url"), tab_hostname);
     const permissionsToCheck = {
