@@ -4,7 +4,9 @@
  */
 
 import { ssoLog, load_icon, ssoLogError } from "./utils.js";
-import { Deferred } from "./utils.js";
+
+/* refresh the token if only x time is left */
+const TOKEN_MIN_VALIDITY_MS = 60 * 1000;
 
 export class Account {
     #broker_obj = null;
@@ -117,14 +119,9 @@ export class Account {
 }
 
 export class AccountManager {
-    #broker = null;
     #registered = [];
     #queried = false;
 
-    constructor(broker) {
-        this.#broker = broker;
-    }
-
     hasAccounts() {
         return this.#registered.length != 0;
     }
@@ -165,13 +162,13 @@ export class AccountManager {
         return account;
     }
 
-    async loadAccounts() {
+    async loadAccounts(broker) {
         if (this.hasBrokerData()) return;
 
         ssoLog("loading accounts");
-        var _accounts = [];
+        let _accounts = [];
         try {
-            _accounts = await this.#broker.getAccounts();
+            _accounts = await broker.getAccounts();
         } catch (error) {
             ssoLog(error);
         }
@@ -193,17 +190,16 @@ export class AccountManager {
             ssoLog("select first account: " + this.getActive().username());
         }
         await Promise.all(
-            this.#registered.map((a) => this.loadProfilePicture(a)),
+            this.#registered.map((a) => this.loadProfilePicture(broker, a)),
         );
     }
 
-    async getToken(account) {
-        if (Date.now() + 60 * 1000 < account.access_token_exp) {
+    async getToken(broker, account) {
+        if (Date.now() + TOKEN_MIN_VALIDITY_MS < account.access_token_exp) {
             return account.access_token;
         }
         try {
-            const graph_token =
-                await this.#broker.acquireTokenSilently(account);
+            const graph_token = await broker.acquireTokenSilently(account);
             ssoLog("API token acquired for " + account.username());
             account.access_token = graph_token.accessToken;
             account.access_token_exp = graph_token.expiresOn;
@@ -214,8 +210,8 @@ export class AccountManager {
         }
     }
 
-    async loadProfilePicture(account) {
-        const graph_token = await this.getToken(account);
+    async loadProfilePicture(broker, account) {
+        const graph_token = await this.getToken(broker, account);
         if (!graph_token) return;
         const response = await fetch(
             "https://graph.microsoft.com/v1.0/me/photos/48x48/$value",
@@ -263,7 +259,7 @@ export class AccountManager {
      */
     async persist() {
         if (!this.hasAccounts()) return;
-        let ssostate = {
+        const ssostate = {
             state: this.getActive() != null,
             accounts: this.getActive()
                 ? this.#registered.map((a) => a.toSerial())
@@ -273,31 +269,27 @@ export class AccountManager {
     }
 
     async restore() {
-        let dfd = new Deferred();
-        chrome.storage.local.get("ssostate", (data) => {
-            let active_acc = undefined;
-            if (!data.ssostate) {
-                ssoLog("no preserved state found");
-                // if the SSO is not explicitly disabled, we assume it is on.
-                dfd.resolve(true);
-                return;
-            }
-            const state_active = data.ssostate.state;
-            if (state_active && data.ssostate.accounts) {
-                this.#registered = data.ssostate.accounts.map((a) =>
-                    Account.fromSerial(a),
+        const data = await chrome.storage.local.get("ssostate");
+        let active_acc = undefined;
+        if (!data.ssostate) {
+            ssoLog("no preserved state found");
+            // if the SSO is not explicitly disabled, we assume it is on.
+            return true;
+        }
+        const state_active = data.ssostate.state;
+        if (state_active && data.ssostate.accounts) {
+            this.#registered = data.ssostate.accounts.map((a) =>
+                Account.fromSerial(a),
+            );
+            if (!state_active) this.logout();
+            active_acc = this.getActive();
+            if (active_acc) {
+                ssoLog(
+                    "temporarily using last-known account: " +
+                        active_acc.username(),
                 );
-                if (!state_active) this.logout();
-                active_acc = this.getActive();
-                if (active_acc) {
-                    ssoLog(
-                        "temporarily using last-known account: " +
-                            active_acc.username(),
-                    );
-                }
             }
-            dfd.resolve(state_active);
-        });
-        return dfd.promise;
+        }
+        return state_active;
     }
 }
