@@ -8,7 +8,7 @@ import { Broker } from "./broker.js";
 import { AccountManager } from "./account.js";
 import { ssoLog } from "./utils.js";
 import { PolicyManager } from "./policy.js";
-import { Device, DeviceManager } from "./device.js";
+import { DeviceManager } from "./device.js";
 
 const PLATFORM = create_platform();
 let broker = null;
@@ -39,14 +39,12 @@ async function on_permissions_changed() {
 async function update_tray(action_needed) {
     chrome.action.enable();
     if (is_operational()) {
-        let account = accountManager.getActive();
-        let imgdata = {};
+        const account = accountManager.getActive();
+        const imgdata = {};
         let icon_title = account.username();
 
         // shorten the title a bit
-        if (PLATFORM.browser == "Thunderbird")
-            icon_title = icon_title.split("@")[0];
-
+        icon_title = PLATFORM.transform_ui_title(icon_title);
         let color = null;
         chrome.action.setTitle({
             title: icon_title,
@@ -79,7 +77,7 @@ async function update_tray(action_needed) {
         });
     }
     // We have limited space on Thunderbird, hence shorten the title
-    if (PLATFORM.browser == "Thunderbird") title = "EntraID SSO disabled";
+    title = PLATFORM.transform_ui_title(title);
     chrome.action.setTitle({ title: title });
 }
 
@@ -102,7 +100,7 @@ function notify_state_change(ui_only = false) {
         );
     }
     if (port_menu === null) return;
-    deviceManager.updateDeviceInfo().then((updated) => {
+    deviceManager.updateDeviceInfo(broker).then((updated) => {
         /* only notify on success to avoid indefinite recursion as errors are not cached */
         if (updated) {
             notify_state_change(true);
@@ -141,9 +139,9 @@ async function on_broker_state_change(online) {
         ssoLog("connection to broker restored");
         // only reload data if we did not see the broker before
         if (!accountManager.hasBrokerData()) {
-            await accountManager.loadAccounts();
+            await accountManager.loadAccounts(broker);
             accountManager.persist();
-            await deviceManager.loadDeviceInfo();
+            await deviceManager.loadDeviceInfo(broker);
             notify_state_change();
         }
     } else {
@@ -152,7 +150,7 @@ async function on_broker_state_change(online) {
     notify_state_change(true);
 }
 
-async function on_storage_changed(changes, areaName) {
+async function on_storage_changed(_changes, areaName) {
     if (areaName == "managed") {
         await policyManager.load_policies();
     }
