@@ -14,7 +14,7 @@ export class RpcHandlerQueue {
     #queue = [];
 
     register_handle(id) {
-        let handle = {
+        const handle = {
             id: id,
             dfd: new Deferred(),
         };
@@ -23,7 +23,7 @@ export class RpcHandlerQueue {
     }
 
     resolve_handle(id, data) {
-        let idx = this.#queue.findIndex((hdl) => hdl.id == id);
+        const idx = this.#queue.findIndex((hdl) => hdl.id == id);
         if (idx !== -1) {
             this.#queue[idx].dfd.resolve(data);
             this.#queue.splice(idx, 1);
@@ -31,7 +31,7 @@ export class RpcHandlerQueue {
     }
 
     reject_handle(id, data) {
-        let idx = this.#queue.findIndex((hdl) => hdl.id == id);
+        const idx = this.#queue.findIndex((hdl) => hdl.id == id);
         if (idx !== -1) {
             this.#queue[idx].dfd.reject(data);
             this.#queue.splice(idx, 1);
@@ -124,9 +124,14 @@ export class Broker {
         }
 
         if (response.command == "acquirePrtSsoCookie") {
+            var cookieData = response.message;
+            /* microsoft-identity-broker > 2.0.1 */
+            if ("cookieItems" in cookieData) {
+                cookieData = cookieData.cookieItems[0];
+            }
             this.#rpc_queue.resolve_handle("acquirePrtSsoCookie", {
-                cookieName: response.message.cookieName,
-                cookieContent: response.message.cookieContent,
+                cookieName: cookieData.cookieName,
+                cookieContent: cookieData.cookieContent,
             });
         } else if (response.command == "getAccounts") {
             let _accounts = [];
