@@ -16,7 +16,7 @@ export class Device {
 }
 
 export class DeviceManager {
-    static DEVICE_REFRESH_INTERVAL_MIN = 30;
+    static DEVICE_REFRESH_INTERVAL_MIN_MS = 30 * 60 * 1000;
 
     #am = null;
     #last_refresh = 0;
@@ -34,26 +34,26 @@ export class DeviceManager {
      * as error states are not cached (to allow recovering after sporadic errors).
      * @returns true if successfully updated
      */
-    async updateDeviceInfo() {
+    async updateDeviceInfo(broker) {
         if (
             Date.now() <
-            this.#last_refresh +
-                DeviceManager.DEVICE_REFRESH_INTERVAL_MIN * 60 * 1000
+            this.#last_refresh + DeviceManager.DEVICE_REFRESH_INTERVAL_MIN_MS
         ) {
             return false;
         }
-        return await this.loadDeviceInfo();
+        return await this.loadDeviceInfo(broker);
     }
 
     /**
      * Load information about the accessing device (e.g. compliance state)
      * @returns true on success
      */
-    async loadDeviceInfo() {
+    async loadDeviceInfo(broker) {
         if (!this.#am.hasAccounts()) {
             return false;
         }
         const graph_token = await this.#am.getToken(
+            broker,
             this.#am.getRegistered()[0],
         );
         if (!graph_token) {
