@@ -3,7 +3,7 @@
  * SPDX-FileCopyrightText: Copyright 2025 Siemens
  */
 
-import { Deferred } from "./utils.js";
+import { ssoLog } from "./utils.js";
 
 export class Platform {
     static SSO_URL = "https://login.microsoftonline.com";
@@ -16,7 +16,6 @@ export class Platform {
     };
 
     /* references needed for PRT injection */
-    broker = null;
     account = null;
     well_known_app_filters = [];
     sso_url_permitted = true;
@@ -50,12 +49,19 @@ export class Platform {
         });
     }
 
+    /**
+     * Can be overwritten to shorten the title on platforms that print the
+     * title next to the icon (instead of in a tooltip).
+     */
+    transform_ui_title(title) {
+        return title;
+    }
+
     getSsoUrl() {
         return Platform.SSO_URL;
     }
 
     update_request_handlers(enabled, account, broker) {
-        this.broker = broker;
         this.account = account;
     }
 
@@ -64,14 +70,10 @@ export class Platform {
         this.well_known_app_filters = currentPermissions.origins;
 
         // check if we have access to the SSO url
-        let dfd = new Deferred();
         const permissionsToCheck = {
             origins: [Platform.SSO_URL + "/*"],
         };
-        chrome.permissions.contains(permissionsToCheck).then((result) => {
-            this.sso_url_permitted = result;
-            dfd.resolve();
-        });
-        await dfd.promise;
+        const result = await chrome.permissions.contains(permissionsToCheck);
+        this.sso_url_permitted = result;
     }
 }
